==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-kbindicator/translations/kbindicator_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>K</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Düzen</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Klavye</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Klavye durum ayarları</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Göstergeler</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Büyük/Küçük Harf</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Sayısal Tuş Takımı Açık/Kapalı</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Kaydırma Açık/Kapalı</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Klavye Düzeni Göstergesi</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Değiştirme Politikası</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Düzeni Yapılandır</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Evrensel</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Uygulama</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-kbindicator/translations/kbindicator_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>K</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Düzen</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Klavye</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Klavye durum ayarları</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Göstergeler</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Büyük Harfi Göster</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Sayısal Tuş Takımını Göster</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Kaydırma Kilidini Göster</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Klavye Düzeni Göstergesi</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Değiştirme politikası</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Düzeni yapılandır</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Evrensel</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Uygulama</translation>
    </message>
</context>
</TS>
